WrappedComponent
================

.. currentmodule:: dash_component_template

.. autoclass:: WrappedComponent
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~WrappedComponent.dash_component_info
      ~WrappedComponent.id
      ~WrappedComponent.idbase
      ~WrappedComponent.layout

   .. rubric:: Methods Summary

   .. autosummary::

      ~WrappedComponent.setup_layout

   .. rubric:: Attributes Documentation

   .. autoattribute:: dash_component_info
   .. autoattribute:: id
   .. autoattribute:: idbase
   .. autoattribute:: layout

   .. rubric:: Methods Documentation

   .. automethod:: setup_layout
